{smcl}
{* *! version 1.00  07jul2016}{...}
{findalias asfradohelp}{...}
{vieweralsosee "" "--"}{...}
{vieweralsosee "[R] help" "help help"}{...}
{viewerjumpto "Syntax" "absmob##syntax"}{...}
{viewerjumpto "Description" "absmob##description"}{...}
{viewerjumpto "Options" "absmob##options"}{...}
{viewerjumpto "Remarks" "absmob##remarks"}{...}
{viewerjumpto "Examples" "absmob##examples"}{...}
{title:Title}

{phang}
{bf:absmob} {hline 2} Calculate absolute mobility statistics


{marker syntax}{...}
{title:Syntax}

{phang}
Compute parents' marginal incomes for specified cohorts

{p 8 10 2}
{cmd:absmob compute} {opt par:_marginals}
{cmd:,} {opth cohorts(numlist)}
[ {opt par:ent(par_options)} {it:common_options} ]


{phang}
Compute kids' marginal incomes for specified cohorts

{p 8 10 2}
{cmd:absmob compute} {opt kid:_marginals}
{cmd:,} {opth cohorts(numlist)}
[ {opt kid:(kid_options)} {it:common_options} ]


{phang}
Compute absolute mobility statistics for specified cohorts. ({it:Assumes marginal incomes have already been generated and stored in {bf:outdir}})

{p 8 10 2}
{cmd:absmob compute} {opt mob:ility}
{cmd:,} {opth cohorts(numlist)}
[ {opt mob:ility(mob_options)} {it:common_options} ]


{phang}
Compute everything - parent & kid marginals, followed by mobility statistics.

{p 8 10 2}
{cmd:absmob compute} {opt all:}
{cmd:,} {opth cohorts(numlist)}
[ {opt par:ent(par_options)} {opt kid:(kid_options)} {opt mob:ility(mob_options)} {it:common_options} ]


{synoptset 45 notes}{...}
{synopthdr}
{synoptline}
{syntab :parent_options}
{synopt:{opt age_at_census(# #)}}Restrict the sample to parents of age between (# #) at the time of the survey. The default is (25 35){p_end}
{synopt:{opt age_at_childbirth(# #)}}Restrict the sample to parents who were in this age range at the time of their childbirth. The default is (16 45){p_end}
{synopt:{opt rep:type( richer | older | mother | father )}}Use this parent's properties to perform sample restrictions. Default is {it:richer}{p_end}
{synopt:{opt gen:der( male | female | all )}}Restrict parents' sample to this gender. Default is {it:all} (i.e., no restriction).{p_end}

{syntab :kid_options}
{synopt:{opt age(#)}}Compute kids' earnings when they're of this age. Default is 30.{p_end}
{synopt:{opt gen:der( male | female | all )}}Restrict sample to kids of this gender. Default is {it:all}.{p_end}
{synopt:{opt imm:igrants( keep | drop )}}Drop or keep immigrants. Default is {it:keep} (data only available 1990 onwards in the CPS).{p_end}

{syntab :mobility_options}
{synopt:{opt cop:ula(copula_file)}}The copula file to use. Defaults to {opt $absmob_indir}/base_copula{p_end}

{syntab :common_options}
{synopt:{opt debug( on | off )}}Sets the debug mode. Intermediate files are preserved and a log file is generated. Defaults to {it:on}.{p_end}
{synopt:{opt ad:just_for_zeroes}}Drop parents with <= 0 incomes before computing marginals; and adjust mobility statistics accordingly. Not set by default. (See Remarks){p_end}
{synopt:{opt dir(dir_options)}}See {opt dir_options}{p_end}
{synopt:{opt inc:ome(income_options)}}See {opt income_options}{p_end}

{syntab :income_options}
{synopt:{opt mea:sure(income_measure)}}The income measure to use. Defaults to {it:incmix}. (See section {opt income_options} for supported values){p_end}
{synopt:{opt div:by(#)}}Divide income by this factor (empty by default). (See section {opt income_options} for details) {p_end}
{synopt:{opt tax:by(#)}}Subtract an estimated federal tax from income. (currently the only supported value is {opt mtr}) {p_end}
{synopt:{opt inf:lator(index_file)}}The inflation index to use. Defaults to {opt $absmob_indir}/cpirs. {p_end}
{synopt:{opt base:year(#)}}The year to which dollar values are inflated. Defaults to 2014{p_end}


{syntab :dir_options}
{synopt:{opt in:dir(path)}}Sets ${bf:absmob_indir}, the folder where the program looks for all input files. This option is {it:required} if {bf:$absmob_indir} is empty.{p_end}
{synopt:{opt out:dir(path)}}Sets ${bf:absmob_outdir}, where all output is saved. (The folder gets created if it doesn't exist). {it:Required} if {bf:$absmob_outdir} is empty.{p_end}
{synopt:{opt work:ingdir(path)}}Sets ${bf:absmob_workingdir}, where the code runs and intermediate files are saved. Defaults to {bf:$absmob_outdir} if empty.{p_end}

{synoptline}
{p2colreset}{...}


{marker description}{...}
{title:Description}

{pstd}
{cmd:absmob} estimates the fraction of kids in each birth-cohort who go on to earn at least as much as their parents in adulthood.  
There are 3 main steps in computing this estmate:

{pstd}
First, we use census data to estimate Parents' mean incomes at at a certain stage of their lifecycle (specified by {opt age_at_census}) at each percentile for each birth-cohort. 
We refer to these estimates as the parents' marginal incomes, or simply {opt par_marginals}. 

{pstd}
Second, we use CPS data to construct kids' mean incomes when they're adults (specified by {opt age}) for each percentile for each cohort. 
We call these the kids' marginal incomes, or {opt kid_marginals} for short.

{pstd}
Finally, for each cohort, we assume we have a 100 X 100 transition matrix (a {opt copula}) that describes the likelihood of a kid born to parents at the i'th percentile ending up at the j'th percentile as an adult.
Using this copula and the marginal incomes, we compute the final set of mobility statistics for each parent-percentile for each cohort. 


{marker options}{...}
{title:Options}

{dlgtab:parent_options}

{phang}
We estimate parents' income at a point in time when they are within the age range specified by {opt age_at_census}. 

{phang}
{opt age_at_childbirth} restricts the parents' sample to those who lie within a certain age range at the time of the birth of their child. 
This option helps eliminate outliers (e.g. those who might have kids at age 15 or 65), and also controls the number of censuses we go back-or-forth to pull out a parent's income.

{phang}
For families where both mother and father are present, {opt rep:type} specifies which parent's attributes are to be used to perform various restrictions (e.g. the age restrictions described above).

{phang}
Specifying {opt gen:der} restricts parents to be of a particular gender, and overwrites {opt reptype} if required. For example, specifying {opt gender(male)} will drop all single mothers from the dataset, and will overwrite {opt reptype} to 'father'.

{dlgtab:kid_options}

{phang}
{opt age} specifies the age at which we wish to measure kids' incomes. Usually it is set to the average of the bounds specified in {opt age_at_census}. {opt gender} restricts the kids' sample to those who are of this gender.
{opt immigrants} is used to drop any kid with a foreign birthplace (as per the IPUMS variable BPL). Since this variable is only available 1990 onwards, the {opt immigrants} flag is ignored for cohorts before (1990 - {opt age})


{dlgtab:mobility_options}

{phang}
{opt copula(copula_file)} The copula file should have the same format as either {bf: base_copula} or {bf:base_copula_by_year}.
{bf:base_copula} contains a 100 X 100 doubly stochastic matrix that describes the odds of a kid born to parents in the i'th percentile growing into an adult who earns at the j'th percentile.
{bf:base_copula_by_year} is similar, except that it contains a matrix for every cohort specified in {opt cohorts}. {bf:base_copula} is interpreted as {bf:base_copula_by_year}, with the same matrix applied to all years in the cohort.

{dlgtab:income_options}

{phang}
The income {opt measure} describes the formula used to construct incomes from IPUMS variables. The table below describes the available income measures and their construction.

{pstd}
Once constructed, these incomes are inflated using {opt inf:lator(index_file)} to their dollar values in {opt baseyear}. An {it:index_file} contains just 2 variables: year and rate, describing the conversion rate in each year. By default, the program looks for the file in {bf:$absmob_indir}, though a full path may be specified. 
Current supported values are {opt cpirs} (CPI-U-RS), {opt gdp} (GDP Deflator), {opt ppi} and {opt pcepi}, but adding a new index is as simple as adding a file. 

{synoptset notes}{...}
{synopthdr: income_measure}
{p2line}
{phang2}
Note: {it:CAPS indicates an IPUMS variable; "+ spouse" is shorthand for adding the spouse's income (using the same variable), if a spouse exists.}

{synopt:{opt incmix}} 	Household income (default){break}
						FTOTINC for 1940-1950s; INCTOT + spouse for 1960s;  (INCTOT + spouse) - (INCWELFR + spouse) thereafter.{break}
						(We use FTOTINC from 1950 to obtain incomes for 1940-1950s to reduce the number of missing values).{p_end}
						
{synopt:{opt inctot}}	Household income, without adjustment for 1940-1950s{break}
						INCWAGE + spouse in 1940s; INCTOT + spouse thereafter {p_end}
						
{synopt:{opt faminc}} 	Family income (includes all co-residing household members){break}
						FTOTINC for census data (parents); FTOTVAL for CPS data (kids).{p_end}
						
{synopt:{opt indinc}} 	Individual income{break}
						Representative parent (or kid's) INCWAGE in 1940-50s; INCTOT in 1960s; INCTOT - INCWELFR thereafter.{p_end}
												
{synopt:{opt incwage}} 	Wage income: INCWAGE + spouse{p_end}

{synopt:{opt inctotmx}}	Total household income, including welfare{break}
						FTOTINC for 1940-1950s; (INCTOT + spouse) thereafter.{p_end}

{synopthdr: divby options}
{p2line}
{phang2}

{synopt:{opt famsize}}	Divide income measure by household size. Usually combined with {opt faminc}{p_end}
{synopt:{opt famsqrt}}	Divide income measure by sqrt of household size. Usually combined with {opt faminc}{p_end}
{synopt:{opt spouses}}	Divide income measure by half for married couples. Usually combined with {opt inc*} except {opt incmix}{p_end}

{p2line}
{p2colreset}{...}


{marker remarks}{...}
{title:Remarks}

{phang}
{bf:Cohort Constraints}: The cohorts for which we can compute results are constrained by the years for which data is available. 
We have Census data from 1941 to 2014; and CPS data from 1970 to 2014. Thus, if we want to compute results for kid-age 30, any cohort x should satisfy the constraints 1941 <= x <= 2014; and 1970 <= x + 30 <= 2014.{break}
Solving for x, we have that mobility statistics can only be computed for cohorts between 1941 and 1984. Similarly, if kid-age were 40, mobility can only be computed for cohorts between 1950 and 1974. 
If the cohorts specified fall outside the constraints, an error is raised.

{phang}
{bf:Adjusting for zeroes}:
We pass {opt adj:ust_for_zeroes} whenever a copula is generated by dropping non-positive parent incomes (as is the case with base_copula).{break}
{opt adj} should be left out if the copula being used kept all parents' incomes, positive or not.

{phang}
{bf:Output}:
Parents and kids' marginal incomes get stored in {bf:par_marginal} and {bf:kid_marginal} respectively. 
{bf:absmob} contains the absolute mobility statistics.
If {opt adjust_parent_zeroes} is set, {bf:parents_frac0} records the fraction of parents earning non-positive incomes in each cohort.{break}

{pstd}
If {opt debug} is on, a logfile ({bf:absmob_log}) and the samples constructed for parents ({bf:sample}<cohort>) are retained in the working directory.


{marker examples}{...}
{title:Examples}

{phang} 
For these series of examples, we set indir & outdir using globals, so we don't need to pass them via dir options{break}
If you have dropbox, you can set indir as follows:{break}
{cmd:. global absmob_indir "$dropbox/absolute_mobility/data/cleandata"}

{phang} 
It is recommended that outdir be outside the dropbox, so that the files you generate don't get synced needlessly.{break}
{cmd:. global absmob_outdir "outdir"}

{phang}
Baseline case{break}
{cmd:. absmob compute all, cohorts(1941/1984) adj}

{phang}
Compute parents' marginals, for parents who are between 35 and 45, using the older parent's age to construct the samples{break}
{cmd:. absmob compute par, cohorts(1941/1984) parent(age_at_census(35 45) age_at_childbirth(16 55) rep(older)) adj}

{phang}
Compute kids' marginals, but exclude all immigrants (Note: immigrants will only be dropped for kids who are {opt age} years old in 1990 or thereafter{break}
{cmd:. absmob compute par, cohorts(1941/1984) kid(immigrants(drop)) adj}

{phang}
Compute individual incomes of Fathers vs Sons. (Note: {it:path_to_custom_copula} can be the full path or path relative to indir). {break}
{cmd:. absmob compute all, cohorts(1941/1984) kid(gender(male)) par(gender(male)) income(measure(indinc)) copula({it:path_to_custom_copula}) adj}

{phang}
Compute baseline mobility, but use the GDP deflator (instead of CPI-U-RS) to inflate incomes; and inflate them to their dollar value in 2011{break}
{cmd:. absmob compute all, cohorts(1941/1984) income(inf(gdp) baseyear(2011)) adj}

{phang}
Use family income and normalize by family (household) size{break}
{cmd:. absmob compute all, cohorts(1941/1984) income(mea(faminc) divby(famsize)) adj}

{phang}
Compute baseline mobility, but use post federal-tax income (where income is estimated by applying marginal tax rates){break}
{cmd:. absmob compute all, cohorts(1941/1984) income(taxby(mtr)) adj}

{phang}
Compute baseline mobility, but use the GDP deflator (instead of CPI-U-RS) to inflate incomes; and inflate them to their dollar value in 2011{break}
{cmd:. absmob compute all, cohorts(1941/1984) income(inf(gdp) baseyear(2011)) adj}

{phang}
Compute mobility, but turn debug off so that the results are generated faster, and there are no intermediate files{break}
{cmd:. absmob compute all, cohorts(1941/1984) adj debug(off)}

{phang}
{* {phang} Plot figures that summarize mobility statistics. ({it:Assumes marginal incomes have already been generated and stored in {bf:outdir}})}
{* {p 8 10 2}}
{* {cmd:absmob plot} [{cmd:,} plot_options dir_options]}
{* {syntab :plot_options}}
{* {synopt:{opth means(numlist)}}Plot cohort-means of absolute mobility for years specified in numlist, or over all cohorts if numlist is empty{p_end}}
{* {synopt:{opth by-percentile(numlist)}}Plot percentile-wise absolute mobility for years in numlist, or for the first, last, and floor(mean) cohort if numlist is empty.{p_end}}
