/* Runs the code to produce the Appendix Figures and Tables */


* Edit these globals to reflect your local paths 
global absmob_indir  "" //The path to the cleaned data directory (see input_clean in README)
global absmob_resultsdir "" //The path to a local folder that will contain all the resulting datasets
global absmob_sourcesdir "" //The path to the folder containing the downloaded source code (e.g. sources.do)

discard
adopath + "$absmob_sourcesdir"
clear
set more off

global image_suffix  png 
global num_levels 500

*********************************************************************
* Fig S1a: Upper Bound Copula in 1980 
*********************************************************************

// prepare copula
insheet using "$absmob_resultsdir/matlab/cop1980_max.txt", tab clear
drop v101
ren v* density*
gen kid_bin = _n
reshape long density, i( kid_bin ) j(par_fam_bin)
label variable kid_bin "Child Income Percentile"
label variable par_fam_bin "Parent Income Percentile"
tempfile copula
save `copula'

// minimum child rank to earn more than parent
use "$absmob_resultsdir/Baseline/figure_input_data", clear
keep parent_percentile cohort inflection
rename (parent_percentile inflection) (par_fam_bin kid_needs)
reshape wide kid_needs, i(par_fam_bin) j(cohort)
merge 1:m par_fam_bin using `copula', nogen

twoway (contour density kid_bin par_fam_bin, ///
	heatmap interp(none) levels(${num_levels}) crule(lin) scolor(white) ecolor(cranberry)) ///
	(line kid_needs1980 par_fam_bin if kid_bin==1, sort(par_fam_bin) c(l) lw(medthick) lpattern(solid) lc(gs0)), ///
	text(65 80 "1980") ///
	xtitle("Parent Income Percentile (conditional on positive income)") ytitle("Child Income Percentile") ///
	title("Figure S1a") ///
	graphregion(color(white)) ///
	ylabel(, angle(0)) ///
	xlab( ,grid) ///
	legend(off) ///
	clegend(off)	
graph export "$absmob_resultsdir/Baseline/figS1a.${image_suffix}", replace


*********************************************************************
* Fig S1b: Lower Bound Copula in 1980 
*********************************************************************

// prepare copula
insheet using "$absmob_resultsdir/matlab/cop1980_min.txt", tab clear
drop v101
ren v* density*
gen kid_bin = _n
reshape long density, i( kid_bin ) j(par_fam_bin)
label variable kid_bin "Child Income Percentile"
label variable par_fam_bin "Parent Income Percentile"
tempfile copula
save `copula'

// minimum child rank to earn more than parent
use "$absmob_resultsdir/Baseline/figure_input_data", clear
keep parent_percentile cohort inflection
rename (parent_percentile inflection) (par_fam_bin kid_needs)
reshape wide kid_needs, i(par_fam_bin) j(cohort)
merge 1:m par_fam_bin using `copula', nogen

twoway (contour density kid_bin par_fam_bin, ///
	heatmap interp(none) levels(${num_levels}) crule(lin) scolor(white) ecolor(cranberry)) ///
	(line kid_needs1980 par_fam_bin if kid_bin==1, sort(par_fam_bin) c(l) lw(medthick) lpattern(solid) lc(gs0)), ///
	text(83 80 "1980") ///
	xtitle("Parent Income Percentile (conditional on positive income)") ytitle("Child Income Percentile") ///
	title("Figure S1b") ///
	graphregion(color(white)) ///
	ylabel(, angle(0)) ///
	xlab( ,grid) ///
	legend(off) ///
	clegend(off)
graph export "$absmob_resultsdir/Baseline/figS1b.png", replace

***************************************************
* Fig S2: CPI - X% p.a., plus GDP Deflator 
***************************************************

// adjust for zeroes and take cohort means
use "$absmob_resultsdir/Robustness/CPI minus 2/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/CPI minus 2/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_cpi2 = mean(abs_mob_pos_par)
gen cohort_means_cpi2 = (1-frac0)*cohort_means_pos_cpi2 + frac0
tempfile absmob_cpi2 
save `absmob_cpi2'

use "$absmob_resultsdir/Robustness/CPI-U/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/CPI-U/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_cpiu = mean(abs_mob_pos_par)
gen cohort_means_cpiu = (1-frac0)*cohort_means_pos_cpiu + frac0
tempfile absmob_cpiu 
save `absmob_cpiu'

use "$absmob_resultsdir/Robustness/GDP/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/GDP/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_gdp = mean(abs_mob_pos_par)
gen cohort_means_gdp = (1-frac0)*cohort_means_pos_gdp + frac0
tempfile absmob_gdp 
save `absmob_gdp'

use "$absmob_resultsdir/Baseline/figure_input_data", clear
bysort cohort: egen cohort_means_pos_cpirs = mean(abs_mob_pos_par)
gen cohort_means_cpirs = (1-frac0)*cohort_means_pos_cpirs + frac0

merge 1:1  cohort parent_percentile using `absmob_cpi2', nogen	
merge 1:1  cohort parent_percentile using `absmob_cpiu', nogen	
merge 1:1  cohort parent_percentile using `absmob_gdp', nogen	

replace cohort_means_cpirs = 100*cohort_means_cpirs
replace cohort_means_cpi2  = 100*cohort_means_cpi2
replace cohort_means_cpiu  = 100*cohort_means_cpiu
replace cohort_means_gdp   = 100*cohort_means_gdp

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_cpirs cohort, connect(direct) msymbol(circle)   col(navy)) ///
   (scatter cohort_means_cpi2  cohort, connect(direct) msymbol(triangle) col(dkorange)) ///
   (scatter cohort_means_cpiu  cohort, connect(direct) msymbol(square)   col(forest_green) mfcol(none)) ///
   (scatter cohort_means_gdp   cohort, connect(direct) msymbol(circle)   col(maroon)       mfcol(none)), ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	xtitle("Child's Birth Cohort") ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(50(10)100, angle(0)) ///
	yscale(range(50 100)) ///
	title("Figure S2") ///
	legend(lab(1 "Baseline: CPI-U-RS") ///
		   lab(2 "CPI-U-RS Minus 2%") ///
		   lab(3 "CPI-U") ///
		   lab(4 "GDP Deflator") ///
		   pos(2) ring(0) c(1) order(1 2 4 3) region(color(none)))
graph export "$absmob_resultsdir/Baseline/figS2.${image_suffix}", replace


***************************************************
* Fig S3: Robustness to Family Size 
***************************************************

// adjust for zeroes and take cohort means
use "$absmob_resultsdir/Robustness/Family Size/Nr of Adults/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Family Size/Nr of Adults/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_ad = mean(abs_mob_pos_par)
gen cohort_means_ad = (1-frac0)*cohort_means_pos_ad + frac0
tempfile absmob_adults 
save `absmob_adults'

use "$absmob_resultsdir/Robustness/Family Size/Total Nr in Family/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Family Size/Total Nr in Family/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_fam = mean(abs_mob_pos_par)
gen cohort_means_fam = (1-frac0)*cohort_means_pos_fam + frac0
tempfile absmob_family 
save `absmob_family'

use "$absmob_resultsdir/Robustness/Family Size/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Family Size/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_famsqrt = mean(abs_mob_pos_par)
gen cohort_means_famsqrt = (1-frac0)*cohort_means_pos_famsqrt + frac0
tempfile absmob_familysqrt 
save `absmob_familysqrt'

// merge and collapse
use "$absmob_resultsdir/Baseline/figure_input_data", clear
bysort cohort: egen cohort_means_pos_nofam = mean(abs_mob_pos_par)
gen cohort_means_nofam = (1-frac0)*cohort_means_pos_nofam + frac0
merge 1:1 cohort parent_percentile using `absmob_adults', nogen
merge 1:1 cohort parent_percentile using `absmob_family', nogen
merge 1:1 cohort parent_percentile using `absmob_familysqrt', nogen
replace cohort_means_nofam   = 100*cohort_means_nofam
replace cohort_means_ad      = 100*cohort_means_ad
replace cohort_means_fam     = 100*cohort_means_fam
replace cohort_means_famsqrt = 100*cohort_means_famsqrt

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_nofam cohort, connect(direct) msymbol(circle)) ///
   (scatter cohort_means_ad    cohort, connect(direct) msymbol(triangle)) ///
   (scatter cohort_means_fam   cohort, connect(direct) msymbol(circle) mfc(none)) , ///
	title("Figure S3") ///
	xtitle("Child's Birth Cohort") ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(50(10)100, angle(0)) ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	legend(lab(1 "Baseline") ///
		   lab(2 "Divide by Nr of Adults") ///
		   lab(3 "Divide by Family Size") ///
		   pos(7) c(1) ring(0) region(color(none)) order(1 2 3))
graph export "$absmob_resultsdir/Baseline/figS3.${image_suffix}", replace


/******************************************
* Fig S4: Raise Children's Income by X
*******************************************/

// adjust for zeroes and take cohort means
foreach x of numlist 100 500 1000 5000(5000)50000 {
	use "$absmob_resultsdir/Robustness/Raise by X/`x'/absmob", clear
	merge m:1 cohort using "$absmob_resultsdir/Robustness/Raise by X/`x'/parents_frac0", nogen 
	bysort cohort: egen cohort_means_pos_raise = mean(abs_mob_pos_par)
	gen cohort_means = (1-frac0)*cohort_means_pos_raise + frac0
	replace cohort_means = 100*cohort_means
	gen raise = `x'
	collapse (lastnm) cohort_means raise
	tempfile absmob_raise`x' 
	save `absmob_raise`x''
}
use "$absmob_resultsdir/Baseline/figure_input_data", clear
keep if cohort == 1984
bysort cohort: egen cohort_means_pos_base = mean(abs_mob_pos_par)
gen cohort_means = (1-frac0)*cohort_means_pos_base + frac0
replace cohort_means = 100*cohort_means
gen raise = 0
collapse (lastnm) cohort_means raise

foreach x of numlist 100 500 1000 5000(5000)50000 {
	append using `absmob_raise`x''	
}
format raise %9.0fc

twoway (line cohort_means raise,  mcolor(navy) lcolor(navy) msymbol(circle) col(navy)), ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	xtitle("Magnitude of Income Increase for Children in 2010") ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(50(10)100, angle(0)) ///
	yscale(range(50 100)) ///
	title("Figure S4") ///
	legend(off)
graph export "$absmob_resultsdir/Baseline/figS4.${image_suffix}", replace


**************************************************
* Fig S5a: Higher Thresholds 
**************************************************

// Adjust for zeroes and take cohort means
use "$absmob_resultsdir/Robustness/Higher Thresholds/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Higher Thresholds/parents_frac0", nogen 
sort cohort threshold parent_percentile
by cohort threshold: egen cohort_means_pos = mean(abs_mob_pos_par)
foreach t of numlist 80 90 100 110 120 {
	gen cohort_means_`t' = (1-frac0)*cohort_means_pos + frac0 if threshold == `t'
	replace cohort_means_`t' = 100*cohort_means_`t'
}
sort cohort threshold parent_percentile

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_80  cohort, connect(direct) msymbol(circle)   color(maroon) mfc(none)) ///
   (scatter cohort_means_100 cohort, connect(direct) msymbol(circle)   color(navy)) ///
   (scatter cohort_means_120 cohort, connect(direct) msymbol(triangle) color(forest_green)) , ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	xtitle("Child's Birth Cohort") ///
	ytitle("Pct. of Children Earning 20% More/Less than Parents") ///
	ylabel(40(10)100, angle(0)) ///
	yscale(range(50 100)) ///
	title("Figure S5a") ///
	legend(lab(1 "20% Less") ///
		   lab(2 "Baseline") ///
		   lab(3 "20% More") pos(2) ring(0) c(1) region(color(none)) order(2 1 3))
graph export "$absmob_resultsdir/Baseline/figS5a.${image_suffix}", replace


**************************************************
* Fig S5b: Median Ratios 
**************************************************

use "$absmob_resultsdir/Baseline/par_marginal.dta", clear
rename percentile par_bin
tempfile par
save `par'

use "$absmob_resultsdir/Baseline/kid_marginal.dta", clear
rename percentile kid_bin
tempfile kid
save `kid'

// expand copula
use "$absmob_indir/copula_base_adjusted.dta", clear 
reshape long p, i(kid_bin) j(par_bin)
expand 45, g(new)
g cohort = .
replace cohort = 1940 if !new
sort kid_bin par_bin cohort
replace cohort = cohort[_n-1]+1 if mi(cohort)
drop new

// merge marginal distributions
merge m:1 par_bin cohort using `par', nogen keep(match) 
merge m:1 kid_bin cohort using `kid', nogen keep(match) 

// construct ratio and collapse
g ratio = kid_inc/par_inc

collapse (median) ratio [w=p], by(cohort) 

scatter ratio cohort , connect(direct) ///
	xtitle("Child's Birth Cohort") ///
	ytitle("Median Kid Income / Parent Income") ///
	title("Figure S5b") ///
	ylab(, angle(horizontal))
graph export "$absmob_resultsdir/Baseline/figS5b.${image_suffix}", replace


**************************************************
* Fig S6: Other Income Definitions 
**************************************************

// Adjust for zeroes and take cohort means
use "$absmob_resultsdir/Baseline/figure_input_data", clear
sort cohort parent_percentile
by cohort: egen cohort_means_pos = mean(abs_mob_pos_par)
gen cohort_means_base = (1-frac0)*cohort_means_pos + frac0
sort cohort parent_percentile
replace cohort_means_base = 100*cohort_means_base
keep parent_percentile cohort cohort_means_base

merge 1:1 cohort parent_percentile ///
	using "$absmob_resultsdir/Robustness/Wages/absmob", assert(3) nogen
merge m:1 cohort using "$absmob_resultsdir/Robustness/Wages/parents_frac0", nogen
sort cohort parent_percentile
by cohort: egen cohort_means_pos = mean(abs_mob_pos_par)
gen cohort_means_incwage = (1-frac0)*cohort_means_pos + frac0
sort cohort parent_percentile
replace cohort_means_incwage = 100*cohort_means_incwage
keep parent_percentile cohort cohort_means_base cohort_means_incwage

merge 1:1 cohort parent_percentile ///
	using "$absmob_resultsdir/Robustness/Family Income/absmob", assert(3) nogen
merge m:1 cohort using "$absmob_resultsdir/Robustness/Family Income/parents_frac0", nogen
sort cohort parent_percentile
by cohort: egen cohort_means_pos = mean(abs_mob_pos_par)
gen cohort_means_faminc = (1-frac0)*cohort_means_pos + frac0
sort cohort parent_percentile
replace cohort_means_faminc = 100*cohort_means_faminc
keep parent_percentile cohort frac0 ///
	cohort_means_base cohort_means_incwage cohort_means_faminc

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_base    cohort, connect(direct) msymbol(circle)) ///
   (scatter cohort_means_incwage cohort, connect(direct) msymbol(circle) mfc(none)) ///
   (scatter cohort_means_faminc  cohort, connect(direct) msymbol(triangle)) , ///
	xtitle("Child's Birth Cohort") ///
	yscale(range(45 100)) ///
	ylabel(50(10)100, angle(0)) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	title("Figure S6") ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	legend(lab(1 "Baseline") lab(2 "Wage Income Only") lab(3 "Family Income") ///
		c(1) ring(0) pos(2))
graph export "$absmob_resultsdir/Baseline/figS6.${image_suffix}", replace


***************************************************
* Fig S7: Immigrants 
***************************************************

// Adjust for zeroes and collapse
use "$absmob_resultsdir/Baseline/figure_input_data", clear
sort cohort parent_percentile
by cohort: egen cohort_means_pos = mean(abs_mob_pos_par)
gen cohort_means_base = (1-frac0)*cohort_means_pos + frac0
sort cohort parent_percentile
replace cohort_means_base = 100*cohort_means_base
keep parent_percentile cohort cohort_means_base frac0
tempfile base
save `base'

use "$absmob_resultsdir/Robustness/Immigrants/absmob", clear
merge m:1 cohort using ///
	"$absmob_resultsdir/Robustness/Immigrants/parents_frac0", nogen 
sort cohort parent_percentile
by cohort: egen cohort_means_pos_imm = mean(abs_mob_pos_par)
gen cohort_means_imm = (1-frac0)*cohort_means_pos_imm + frac0
sort cohort parent_percentile
replace cohort_means_imm = 100*cohort_means_imm
merge 1:1 cohort parent_percentile using `base', assert(3) nogen

collapse (mean) cohort_means_*, by(cohort)

// note the series are the same before 1964
twoway (scatter cohort_means_base cohort, connect(direct) msymbol(circle)) ///
	(scatter cohort_means_imm cohort if inrange(cohort,1964,1984), connect(direct) msymbol(triangle)) , ///
	xtitle("Child's Birth Cohort") ///
	ylabel(50(10)100, angle(0)) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	title("Figure S7") ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	legend(lab(1 "Baseline") lab(2 "Including Immigrants") ///
		c(1) pos(2) ring(0))

graph export "$absmob_resultsdir/Baseline/figS7.${image_suffix}", replace


***************************************************
* Fig S8: Age Definitions 
***************************************************

// Adjust for zeroes and collapse
use "$absmob_resultsdir/Baseline/figure_input_data", clear
sort cohort parent_percentile
by cohort: egen cohort_means_pos = mean(abs_mob_pos_par)
gen cohort_means_base = (1-frac0)*cohort_means_pos + frac0
sort cohort parent_percentile
replace cohort_means_base = 100*cohort_means_base
keep parent_percentile cohort cohort_means_base frac0
tempfile base
save `base'

use "$absmob_resultsdir/Robustness/Parent 25-35/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Parent 25-35/parents_frac0", nogen
sort cohort parent_percentile
by cohort: egen cohort_means_pos_2535 = mean(abs_mob_pos_par)
gen cohort_means_2535 = (1-frac0)*cohort_means_pos_2535 + frac0
sort cohort parent_percentile
replace cohort_means_2535 = 100*cohort_means_2535

merge 1:1 cohort parent_percentile using `base', assert(3) nogen

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_base cohort, connect(direct)) ///
   (scatter cohort_means_2535 cohort, connect(direct) msymbol(triangle)) , ///
	xtitle("Child's Birth Cohort") ///
	ylabel(50(10)100, angle(0)) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	title("Figure S8") ///
	legend(lab(1 "Baseline") lab(2 "Child Income at 30" "Parents Matched at 25-35") ///
		c(1) ring(0) pos(2))
	
graph export "$absmob_resultsdir/Baseline/figS8.${image_suffix}", replace


***************************************************
* Fig S9: CPS-CPS and Census-Census 
***************************************************

// Adjust for zeroes and take cohort means
use "$absmob_resultsdir/Robustness/CPS-CPS/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/CPS-CPS/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_cps = mean(abs_mob_pos_par)
gen cohort_means_cps = (1-frac0)*cohort_means_pos_cps + frac0
tempfile absmob_cps 
save `absmob_cps'

use "$absmob_resultsdir/Robustness/Census-Census/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Census-Census/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_census = mean(abs_mob_pos_par)
gen cohort_means_census = (1-frac0)*cohort_means_pos_census + frac0
tempfile absmob_census 
save `absmob_census'

use "$absmob_resultsdir/Baseline/figure_input_data", clear
bysort cohort: egen cohort_means_pos_base = mean(abs_mob_pos_par)
gen cohort_means_base = (1-frac0)*cohort_means_pos_base + frac0
merge 1:1 cohort parent_percentile using `absmob_cps', nogen
merge 1:1 cohort parent_percentile using `absmob_census', nogen
replace cohort_means_base   = 100*cohort_means_base
replace cohort_means_cps    = 100*cohort_means_cps
replace cohort_means_census = 100*cohort_means_census

collapse (mean) cohort_means_*, by(cohort)

tw  (scatter cohort_means_base   cohort, connect(l) msymbol(circle))   ///
	(scatter cohort_means_cps    cohort, connect(l) msymbol(triangle))   ///
	(scatter cohort_means_census cohort, connect(l) lpattern(dash) msymbol(circle)) , ///
	xtitle("Child's Birth Cohort") ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(40(10)100, angle(0))  ///
	title("Figure S9") ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	legend(lab(1 "Baseline") ///
		   lab(2 "CPS Only") ///
		   lab(3 "Census Only") ///
		   ring(0) pos(1) c(1) region(color(none)))
graph export "$absmob_resultsdir/Baseline/figS9.${image_suffix}", replace


***************************************************
* Fig S10: Gender 
***************************************************

// Father - Son Individual
use "$absmob_resultsdir/Robustness/Sons/Fathers/Individual Income/absmob", clear
merge m:1 cohort using ///
	"$absmob_resultsdir/Robustness/Sons/Fathers/Individual Income/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_sf_indv = mean(abs_mob_pos_par)
gen cohort_means_sf_indv = (1-frac0)*cohort_means_pos_sf_indv + frac0
keep parent_percentile cohort cohort_means_sf_indv
replace cohort_means_sf_indv = 100*cohort_means_sf_indv
tempfile absmob_sf_indv
save `absmob_sf_indv'

// Father - Son Household Income
use "$absmob_resultsdir/Robustness/Sons/Fathers/household income/absmob", clear
merge m:1 cohort using ///
	"$absmob_resultsdir/Robustness/Sons/Fathers/household income/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_sf_base = mean(abs_mob_pos_par)
gen cohort_means_sf_base = (1-frac0)*cohort_means_pos_sf_base + frac0
keep parent_percentile cohort cohort_means_sf_base
replace cohort_means_sf_base = 100*cohort_means_sf_base
tempfile absmob_sf_base
save `absmob_sf_base'

// Father - Daughter: Individual
use "$absmob_resultsdir/Robustness/Daughters/individual/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Daughters/individual/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_daughters = mean(abs_mob_pos_par)
gen cohort_means_df_indv = (1-frac0)*cohort_means_pos_daughters + frac0
keep parent_percentile cohort cohort_means_df_indv
replace cohort_means_df_indv = 100*cohort_means_df_indv
tempfile absmob_df_indv
save `absmob_df_indv'

// Father - Daughter: Household Income
use "$absmob_resultsdir/Robustness/Daughters/household/absmob", clear
merge m:1 cohort using "$absmob_resultsdir/Robustness/Daughters/household/parents_frac0", nogen 
bysort cohort: egen cohort_means_pos_daughters = mean(abs_mob_pos_par)
gen cohort_means_df_base = (1-frac0)*cohort_means_pos_daughters + frac0
keep parent_percentile cohort cohort_means_df_base
replace cohort_means_df_base = 100*cohort_means_df_base
tempfile absmob_df_base
save `absmob_df_base'


// Baseline
use "$absmob_resultsdir/Baseline/figure_input_data", clear
bysort cohort: egen cohort_means_pos_base = mean(abs_mob_pos_par)
gen cohort_means_base = (1-frac0)*cohort_means_pos_base + frac0
drop abs_mob cohort_means_pos_base
replace cohort_means_base  = 100*cohort_means_base
tempfile base
save `base'

// S4: Fathers
use `base', clear
merge 1:1 cohort parent_percentile using `absmob_sf_indv', assert(3) nogen
merge 1:1 cohort parent_percentile using `absmob_sf_base', assert(3) nogen
merge 1:1 cohort parent_percentile using `absmob_df_indv', assert(3) nogen
merge 1:1 cohort parent_percentile using `absmob_df_base', assert(3) nogen

collapse (mean) cohort_means_*, by(cohort)

tw (scatter cohort_means_base    cohort, connect(direct) msymbol(circle)) ///
   (scatter cohort_means_sf_indv cohort, connect(direct) msymbol(circle)   mfc(none)) ///
   (scatter cohort_means_sf_base cohort, connect(direct) msymbol(triangle)) ///
   (scatter cohort_means_df_indv cohort, connect(direct) msymbol(square)   mfc(none)) ///
   (scatter cohort_means_df_base cohort, connect(direct) msymbol(triangle) mfc(none)), ///
	title("Figure S10") ///
	xtitle("Child's Birth Cohort") ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(20(10)100, angle(0)) ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) ///
	legend(lab(1 "Baseline") ///
		   lab(2 "Son vs. Father Individual Income") ///
		   lab(3 "Son vs. Parents' Family Income") ///
		   lab(4 "Daughter vs. Father Individual Income") ///
		   lab(5 "Daughter vs. Parents' Family Income") ///
		   region(color(none)) c(1) ring(0) pos(2) order(1 3 5 2 4))
graph export "$absmob_resultsdir/Baseline/figS10.${image_suffix}", replace


******************************************************
* Fig S11: CPS Income Check 
******************************************************

global cpscomp "$absmob_resultsdir/Robustness/Median Income Trends"

// CPS Sons
use "$cpscomp/CPS_to_match_Census_Table_sons.dta", clear
replace year = year-1
rename inc_kid sons_nozero
tempfile sonsdata
save `sonsdata', replace

// CPS Daughters
use "$cpscomp/CPS_to_match_Census_Table_daughters.dta", clear
replace year = year-1
rename inc_kid daughters_nozero
tempfile daughtersdata
save `daughtersdata', replace

// Census
import excel using "$absmob_indir/Census_Historical_Income_P8.xlsx", clear firstrow
rename Men Census_Men
rename Women Census_Women
rename Year year
merge 1:1 year using `sonsdata', nogen
merge 1:1 year using `daughtersdata', nogen

twoway ///
	line sons_nozero      year , lp(dash)  lc(blue) ||  ///
	line Census_Men       year , lp(solid) lc(blue) ||  ///
	line daughters_nozero year , lp(dash)  lc(red)  ||  ///
	line Census_Women     year , lp(solid) lc(red)  ||, ///
	title("Figure S11") ///
	xlabel(1970(10)2010, grid) ///
	graphregion(lcolor(none) ilcolor(none) fcolor(white)) plotregion(lcolor(none)  style(none) icolor(white) fcolor(white)) ///
	ytitle("Income (Real 2014$)") ylabel(, angle(0)) /// 
	xtitle("Year") xlabel(, grid) ///
	legend(label(1 "Our Sample - Males") ///
		   label(2 "CPS Historical Income Tables - Males") ///
		   label(3 "Our Sample - Females") ///
		   label(4 "CPS Historical Income Tables - Females") order(1 2 3 4) pos(4) ring(0) c(1) region(color(none)))		
graph export "$absmob_resultsdir/Baseline/figS11.${image_suffix}", replace


***********************************************
* Fig S12a: Age 40 Counterfactual growth
*********************************************** 

// import cohort means
use "$absmob_resultsdir/Baseline/counterfactuals_summary", clear
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}
local obs40 : di %3.1f abs_mob_1940obs_40
local obs70 : di %3.1f abs_mob_1970obs_40
local hh : di %3.1f abs_mob_1970hh_40
local ll : di %3.1f abs_mob_1970ll_40

// Rescale counterfactuals to percentage
use "$absmob_resultsdir/Baseline/counterfactuals", clear
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}

tw (line abs_mob_1940obs_40 abs_mob_1970obs_40 parent) ///
	(line abs_mob_1970ll_40 parent, lp(dash)) ///
	(line abs_mob_1970hh_40 parent, lp(shortdash_dot)), ///
	xlabel(0(20)100, grid) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(, angle(0)) /// 
	xtitle("Parent Income Percentile (conditional on positive income)") xlabel(, grid) ///
	title("Figure S12a") ///
	text(87 85 "1940 Empirical", size(small)) ///
	text(27 85 "1970 Empirical", size(small)) ///
	text(95 50 "Mean AM:`obs40'%" ///
		80 50 "Mean AM:`ll'%" ///
		64 50 "Mean AM:`hh'%" ///
		48 50 "Mean AM:`obs70'%" , size(small)) ///
	legend(order(3 4) label(4 "1940 GDP/family growth rate (2.5%), 1970 income shares") ///
		label(3 "1970 GDP/family growth rate (1.5%), 1940 income shares") ///
		pos(7) ring(0) region(color(none)) c(1) size(small))		

graph export "$absmob_resultsdir/Baseline/FigS12a.${image_suffix}" , replace


***********************************************
* Fig S12b: Age 30 Growth shares
*********************************************** 
// Import cohort means
use "$absmob_resultsdir/Baseline/counterfactuals_summary", clear
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}
local obs40 : di %3.1f abs_mob_1940obs
local obs80 : di %3.1f abs_mob_1980obs
local hh : di %3.1f abs_mob_1980hhgr
local ll : di %3.1f abs_mob_1980llgr

// Rescale to percentages
use "$absmob_resultsdir/Baseline/counterfactuals", clear
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}

tw (line abs_mob_1940obs abs_mob_1980obs parent) ///
   (line abs_mob_1980llgr parent, lp(dash)) ///
   (line abs_mob_1980hhgr parent, lp(shortdash_dot)), ///
	xlabel(0(20)100, grid) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(, angle(0)) /// 
	xtitle("Parent Income Percentile (conditional on positive income)") xlabel(, grid) ///
	title("Figure S12b") ///
	text(95 85 "1940 Empirical", size(small)) ///
	text(27 85 "1980 Empirical", size(small)) ///
	text(98 50 "Mean AM:`obs40'%" ///
		77 50 "Mean AM:`ll'%" ///
		51 50 "Mean AM:`obs80'%" ///
		37 50 "Mean AM:`hh'%", size(small)) ///
	legend(order(3 4) label(4 "1940 GDP/family growth rate (2.5%), 1980 income growth shares") ///
		label(3 "1980 GDP/family growth rate (1.5%), 1940 income growth shares") ///
		pos(7) ring(0) region(color(none)) c(1) size(small))		

graph export "$absmob_resultsdir/Baseline/FigS12b.${image_suffix}" , replace


***********************************************
* Fig S12c: Age 40 Counterfactual growth shares
*********************************************** 
// Import cohort means
use "$absmob_resultsdir/Baseline/counterfactuals_summary", clear
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}
local obs40 : di %3.1f abs_mob_1940obs_40
local obs70 : di %3.1f abs_mob_1970obs_40
local hh : di %3.1f abs_mob_1970hhgr_40
local ll : di %3.1f abs_mob_1970llgr_40

// Rescale to percentages
use "$absmob_resultsdir/Baseline/counterfactuals", clear
keep parent_percentile *_40
foreach var of varlist abs_mob* {
	replace `var' = 100*`var'
	}

tw (line abs_mob_1940obs_40 abs_mob_1970obs_40 parent) ///
   (line abs_mob_1970llgr_40 parent, lp(dash)) ///
   (line abs_mob_1970hhgr_40 parent, lp(shortdash_dot)), ///
	xlabel(0(20)100, grid) ///
	ytitle("Pct. of Children Earning more than their Parents") ///
	ylabel(, angle(0)) /// 
	xtitle("Parent Income Percentile (conditional on positive income)") xlabel(, grid) ///
	title("Figure S12c") ///
	text(87 85 "1940 Empirical", size(small)) ///
	text(27 85 "1970 Empirical", size(small)) ///
	text(95 50 "Mean AM:`obs40'%" ///
		76 50 "Mean AM:`ll'%" ///
		64 50 "Mean AM:`hh'%" ///
		48 50 "Mean AM:`obs70'%" , size(small)) ///
	legend(order(3 4) label(4 "1940 GDP/family growth rate (2.5%), 1970 income growth shares") ///
		label(3 "1970 GDP/family growth rate (1.5%), 1940 income growth shares") ///
		pos(7) ring(0) region(color(none)) c(1) size(small))		

graph export "$absmob_resultsdir/Baseline/FigS12c.${image_suffix}" , replace


***********************************************
* Table S1: Summary Statistics
*********************************************** 

	gen cohort = .
	gen sample_size = .
	gen mean_inc = .
	gen median_inc = .
	gen implied_cohort_size = .
	tempfile summary_stats_kids
	save    `summary_stats_kids', replace 
	
	foreach cohort of numlist 1940/1984 { 
		u "$absmob_resultsdir/Baseline/kid_sample_`cohort'", clear
		count
		gen sample_size = r(N)
		su income [aw=wtsupp], mean
		gen mean_inc = round(r(mean))
		pctile median_inc = income [pw=wtsupp], n(2) //not the same as in kid_marginal, where we take the average within percentile bins
		replace median_inc = round(median_inc)
		count if marst == 1
		gen percent_married = r(N)/sample_size
		replace percent_married = round(percent_married, .001)
		if `cohort'==1984 replace wtsupp = wtsupp/2  //see https://cps.ipums.org/cps/three_eighths.shtml
		gen popwt = round(wtsupp)
		su id [fw=popwt]
		gen implied_cohort_size = r(N)
		gen cohort = `cohort'
		keep cohort sample_size mean_inc median_inc implied_cohort_size  
		drop in 2/l
		append using `summary_stats_kids'
		save `summary_stats_kids', replace
	}
	sort cohort
	order cohort sample_size mean_inc median_inc implied_cohort_size 
	label var cohort "Cohort"
	label var sample_size "Sample Size"
	label var mean_inc "Mean Income"
	label var median_inc "Median Income"
    label var implied_cohort_size "Weights-Implied Cohort Size"
	format mean_inc median_inc implied_cohort_size %9.0fc
	compress
	export delim using "$absmob_resultsdir/Baseline/TableS1_kids.csv",  dataf replace

	clear
	set more off
	gen cohort = .
	gen n_kids = .
	gen n_parents = .
	gen mean_inc = .
	gen median_inc = .
	tempfile summary_stats_parents
	save    `summary_stats_parents', replace 
	
	foreach cohort of numlist 1940/1984 { 
		use "$absmob_resultsdir/Baseline/par_sample_`cohort'", clear
		gen cohort = `cohort'
		
		su income [fw=weights]
		local sum_weights = round(r(sum_w)/1000000) //we multiply the weights by 1 million in the ado-file because fweights don't allow decimals
		gen n_kids = `sum_weights'
		
		su income if marst==1 [fw=weights]
		local married = round(r(sum_w)/1000000)
		gen n_parents = `sum_weights' + `married' // = number of individuals who are parents, not number of couples  

		su income [fw=weights], mean
		gen mean_inc = round(r(mean))
		
		pctile median_inc = income [fw=weights], n(2) //not the same as in par_marginal, where we take the average within percentile bins
		replace median_inc = round(median_inc)			
		
		su income if marst != 1 [fw=weights]
		local not_married = round(r(sum_w)/1000000)		
		gen percent_married = round((`married'/(`married'+`not_married')), 0.001)
		
		keep cohort n_kids n_parents mean_inc median_inc   
		drop in 2/l
		append using `summary_stats_parents'
		save `summary_stats_parents', replace		
	}
	label var cohort "Cohort"
	label var n_kids "Number of Children"
	label var n_parents "Number of Parents"
	label var mean_inc "Mean Income"
	label var median_inc "Median Income"
	format n_kids n_parents mean_inc median_inc %9.0fc
	compress
	sort cohort
	order cohort n_kids n_parents mean_inc median_inc   
	export delim using "$absmob_resultsdir/Baseline/TableS1_parents.csv", dataf replace

	
***********************************************
* Table S2: State Absolute Mobility Rates
*********************************************** 

// Adjust for zeroes and take cohort means
use "$absmob_resultsdir/Robustness/States/absmob", clear
merge m:1 state cohort using "$absmob_resultsdir/Robustness/States/parents_frac0", nogen 
bysort state cohort: egen cohort_means_pos_st = mean(abs_mob_pos_par)
gen cohort_means = (1-frac0)*cohort_means_pos_st + frac0
collapse (mean) cohort_means, by(state state_name cohort)
drop if mi(cohort_means)
reshape wide cohort_means, i(state) j(cohort)
drop state
order state_name cohort_means* 

export excel "$absmob_resultsdir/Baseline/tableS2", replace




