*A simple program that generates ntiles in the special case where the number of observations are fewer than ntiles themselves
*Assumes the data are already subset to the no. of observations we wish to classify into ntiles.
program define mixtile, rclass

	*y contains the variable we wish to classify (e.g. income) 
	*nq contains the number of ntiles we wish to classify the data into
	*newvar will contain the ntile variable
	*weights -- an optional column describing the weights to assign each obs. Only Fweights supported.
	args y nq newvar weights

	local nobs `=_N' //The original number of observations
	
	if `nobs' < `nq'{
			
		*We assume y (income) is a function of x (percentile), 
		*and we only have values for specific, equally spaced x's
		
		sort `y'
		
		*handle weights
		if "`weights'" == ""{
			tempvar weights 
			gen `weights' = 100
		}
		tempvar cum_wt tot_wt x
		gen `cum_wt' = sum(`weights') //this is the cumulative sum up to obs _n
		egen `tot_wt' = sum(`weights') //this is the total sum of wts
		gen `x' = 100 * `cum_wt'/`tot_wt'

		*Add nq empty rows, and fill them with ntiles from 1 to nq
		local newobs = `nobs' + `nq' 
		set obs `newobs' 
		replace `x' = _n - `nobs' if mi(`x')
		sort `x'
		
		*Handle the case where nq is an exact multiple of nobs
		tempvar xdup
		duplicates tag `x', gen(`xdup')
		drop if `xdup' & mi(`y')
		
		*(assuming nq is not a multiple of nobs) at this stage, 
		*we have percentiles (x) that look like 1, 1.45, 2, 2.9..
		*with missing incomes (y) for all integer percentiles.
		*Generate them by linear inter/extrapolation.
		tempvar y_ipolated
		ipolate `y' `x', gen(`y_ipolated') epolate
		replace `y' = `y_ipolated' if mi(`y')
		gen `newvar' = `x'
	}
	else{
		display "The number of obs is greater than the number of ntiles to split into; doing nothing"
        exit
	}
end
